@@ -85,9 +85,9 @@ class TqdmDefaultWriteLock(object):
         cls = type(self)
         self.locks = [lk for lk in [cls.mp_lock, cls.th_lock] if lk is not None]
 
-    def acquire(self):
+    def acquire(self, *a, **k):
         for lock in self.locks:
-            lock.acquire()
+            lock.acquire(*a, **k)
 
     def release(self):
         for lock in self.locks[::-1]:  # Release in inverse order of acquisition
@@ -774,7 +774,8 @@ class tqdm(Comparable):
                  miniters=None, ascii=None, disable=False, unit='it',
                  unit_scale=False, dynamic_ncols=False, smoothing=0.3,
                  bar_format=None, initial=0, position=None, postfix=None,
-                 unit_divisor=1000, write_bytes=None, gui=False, **kwargs):
+                 unit_divisor=1000, write_bytes=None, lock_args=None,
+                 gui=False, **kwargs):
         """
         Parameters
         ----------
@@ -871,6 +872,9 @@ class tqdm(Comparable):
             If (default: None) and `file` is unspecified,
             bytes will be written in Python 2. If `True` will also write
             bytes. In all other cases will default to unicode.
+        lock_args  : tuple, optional
+            Passed to `refresh` for intermediate output
+            (initialisation, iterating, and updating).
         gui  : bool, optional
             WARNING: internal parameter - do not use.
             Use tqdm.gui.tqdm(...) instead. If set, will attempt to use
@@ -977,6 +981,7 @@ class tqdm(Comparable):
         self.unit = unit
         self.unit_scale = unit_scale
         self.unit_divisor = unit_divisor
+        self.lock_args = lock_args
         self.gui = gui
         self.dynamic_ncols = dynamic_ncols
         self.smoothing = smoothing
@@ -1005,8 +1010,7 @@ class tqdm(Comparable):
         if not gui:
             # Initialize the screen printer
             self.sp = self.status_printer(self.fp)
-            with self._lock:
-                self.display()
+            self.refresh(lock_args=self.lock_args)
 
         # Init the time counter
         self.last_print_t = self._time()
@@ -1103,8 +1107,7 @@ class tqdm(Comparable):
                         self.avg_time = avg_time
 
                     self.n = n
-                    with self._lock:
-                        self.display()
+                    self.refresh(lock_args=self.lock_args)
 
                     # If no `miniters` was specified, adjust automatically
                     # to the max iteration rate seen so far between 2 prints
@@ -1187,8 +1190,7 @@ class tqdm(Comparable):
                         " instead of `tqdm(..., gui=True)`\n",
                         fp_write=getattr(self.fp, 'write', sys.stderr.write))
 
-                with self._lock:
-                    self.display()
+                self.refresh(lock_args=self.lock_args)
 
                 # If no `miniters` was specified, adjust automatically to the
                 # maximum iteration rate seen so far between two prints.
@@ -1270,16 +1272,32 @@ class tqdm(Comparable):
         if not nolock:
             self._lock.release()
 
-    def refresh(self, nolock=False):
-        """Force refresh the display of this bar."""
+    def refresh(self, nolock=False, lock_args=None):
+        """
+        Force refresh the display of this bar.
+
+        Parameters
+        ----------
+        nolock  : bool, optional
+            If `True`, does not lock.
+            If [default: `False`]: calls `acquire()` on internal lock.
+        lock_args  : tuple, optional
+            Passed to internal lock's `acquire()`.
+            If specified, will only `display()` if `acquire()` returns `True`.
+        """
         if self.disable:
             return
 
         if not nolock:
-            self._lock.acquire()
+            if lock_args:
+                if not self._lock.acquire(*lock_args):
+                    return False
+            else:
+                self._lock.acquire()
         self.display()
         if not nolock:
             self._lock.release()
+        return True
 
     def unpause(self):
         """Restart tqdm timer from last print time."""
